@@ -2,17 +2,17 @@
   tuxpaint-config.c
 
   Tux Paint Configuration Tool - A GUI configuration editor for Tux Paint,
-                                 a simpel drawing program for children.
+                                 a simple drawing program for children.
+
+  Copyright (c) 2002-2021
 
-  Copyright (c) 2002-2008
-  
   Torsten Giebl <wizard@turricane.org>
   Jan Wynholds
   Bill Kendrick <bill@newbreedsoftware.com>
 
   http://www.tuxpaint.org/
-  
-  November 12, 2002 - July 14, 2008
+
+  November 12, 2002 - November 15, 2021
 */
 
 
@@ -57,11 +57,10 @@
 
 /* Local function prototypes: */
 
-void setup(int argc, char * argv[]);
-int mainloop(int argc, char * argv[]);
+void setup(int argc, char *argv[]);
+int mainloop(int argc, char *argv[]);
 
-
-int main(int argc, char * argv[])
+int main(int argc, char *argv[])
 {
   int res;
 
@@ -77,26 +76,27 @@ int main(int argc, char * argv[])
 }
 
 
-int mainloop(int argc, char * argv[])
+int mainloop(int argc, char *argv[])
 {
-    Fl::scheme ("none");	
-    Show_TPC_Window ();
+  Fl::scheme("none");
+  Show_TPC_Window();
 
-    return Fl::run ();
+  return Fl::run();
 }
 
 
-void setup(int argc, char * argv[])
+void setup(int argc, char *argv[])
 {
   int i;
   int show_usage;
   int exit_val;
-    
+  char * tmp_str;
+
 #if !defined (__WIN32__) && !defined(__APPLE__) && !defined(__BEOS__)
-  const struct paper * ppr;
+  const struct paper *ppr;
   int max_papersizes;
 #endif
-    
+
   show_usage = 0;
   exit_val = 0;
 
@@ -146,22 +146,22 @@ void setup(int argc, char * argv[])
       printf("\nTux Paint Config. version " VER_VERSION ", " VER_DATE "\n\n");
 
       printf("This program is free software; you can redistribute it\n"
-	     "and/or modify it under the terms of the GNU General Public\n"
-	     "License as published by the Free Software Foundation;\n"
-	     "either version 2 of the License, or (at your option) any\n"
-	     "later version.\n"
-	     "\n"
-	     "This program is distributed in the hope that it will be\n"
-	     "useful and entertaining, but WITHOUT ANY WARRANTY; without\n"
-	     "even the implied warranty of MERCHANTABILITY or FITNESS\n"
-	     "FOR A PARTICULAR PURPOSE.  See the GNU General Public\n"
-	     "License for more details.\n"
-	     "\n"
-	     "You should have received a copy of the GNU General Public\n"
-	     "License along with this program; if not, write to the Free\n"
-	     "Software Foundation, Inc., 59 Temple Place, Suite 330,\n"
-	     "Boston, MA  02111-1307  USA\n\n");
-	exit(0);  
+             "and/or modify it under the terms of the GNU General Public\n"
+             "License as published by the Free Software Foundation;\n"
+             "either version 2 of the License, or (at your option) any\n"
+             "later version.\n"
+             "\n"
+             "This program is distributed in the hope that it will be\n"
+             "useful and entertaining, but WITHOUT ANY WARRANTY; without\n"
+             "even the implied warranty of MERCHANTABILITY or FITNESS\n"
+             "FOR A PARTICULAR PURPOSE.  See the GNU General Public\n"
+             "License for more details.\n"
+             "\n"
+             "You should have received a copy of the GNU General Public\n"
+             "License along with this program; if not, write to the Free\n"
+             "Software Foundation, Inc., 59 Temple Place, Suite 330,\n"
+             "Boston, MA  02111-1307  USA\n\n");
+      exit(0);
     }
     else if (strcmp(argv[i], "--version") == 0)
     {
@@ -177,8 +177,7 @@ void setup(int argc, char * argv[])
 
   if (show_usage)
   {
-    printf("Usage: %s [--version | --copying | --usage | --help]\n",
-           argv[0]);
+    printf("Usage: %s [--version | --copying | --usage | --help]\n", argv[0]);
 
     /* Kluge to get around OS X sending arguments to apps; jdrake 2004-10-02 */
 #ifndef __APPLE__
@@ -187,7 +186,12 @@ void setup(int argc, char * argv[])
   }
 
 
-  setlocale(LC_ALL,"");
+  tmp_str = setlocale(LC_ALL, "");
+  if (tmp_str != NULL) {
+    tpc_locale = strdup(tmp_str);
+  } else {
+    tpc_locale = NULL;
+  }
 
   bindtextdomain("tuxpaint-config", LOCALEDIR);
   /* Old version of glibc does not have bind_textdomain_codeset() */
@@ -203,12 +207,12 @@ void setup(int argc, char * argv[])
   paperinit();
 
   max_papersizes = 5;
-  papersizes = (char * *) malloc(sizeof (char * *) * max_papersizes);
+  papersizes = (char * *) malloc(sizeof(char * *) * max_papersizes);
 
   papersizes[0] = strdup(gettext("(Use system's default)"));
   num_papersizes = 1;
   ppr = paperfirst();
-  
+
   do
   {
     if (ppr != NULL)
@@ -216,7 +220,8 @@ void setup(int argc, char * argv[])
       if (num_papersizes >= max_papersizes)
       {
         max_papersizes += 5;
-        papersizes = (char * *) realloc(papersizes, sizeof(char * *) * max_papersizes);
+        papersizes =
+          (char * *) realloc(papersizes, sizeof(char * *) * max_papersizes);
       }
 
       papersizes[num_papersizes++] = strdup(papername(ppr));
